process FASTP {
    tag "Fastp"
    container 'quay.io/biocontainers/fastp:0.20.0--hdbcaa40_0'
    
    input:
        path fastq1
        path fastq2
        val threads
        val cut_right_window_size
        val cut_right_mean_quality
        val trim_tail1
        val length_required

    output:
        path "${fastq1.simpleName}.trimmed.fastq", emit: paired_fastq1
        path "${fastq2.simpleName}.trimmed.fastq", emit: paired_fastq2
        path "${fastq1.simpleName}.unpaired.trimmed.fastq", emit: unpaired_fastq1
        path "${fastq2.simpleName}.unpaired.trimmed.fastq", emit: unpaired_fastq2
        path "*.html", emit: html_report
        path "*.json", emit: json_report
        
    script:    

        """
        fastp \
            -o ${fastq1.simpleName}.trimmed.fastq \
            -O ${fastq2.simpleName}.trimmed.fastq \
            --unpaired1 ${fastq1.simpleName}.unpaired.trimmed.fastq \
            --unpaired2 ${fastq2.simpleName}.unpaired.trimmed.fastq \
            --cut_right \
            --cut_right_mean_quality $cut_right_mean_quality \
            --cut_right_window_size $cut_right_window_size \
            -i $fastq1 \
            -I $fastq2 \
            --length_required $length_required \
            --trim_tail1 $trim_tail1 \
            --thread $threads
        """
}